@@ -16,28 +16,58 @@
 #' get_favourited_by(id = "109326579599502650")
 #' }
 #' @export
-get_status <- function(id, instance = NULL, token = NULL, anonymous = FALSE, parse = TRUE) {
+get_status <- function(
+    id,
+    instance = NULL,
+    token = NULL,
+    anonymous = FALSE,
+    parse = TRUE
+) {
     process_request(
-        token = token, path = paste0("/api/v1/statuses/", id), instance = instance,
-        anonymous = anonymous, parse = parse, FUN = parse_status
+        token = token,
+        path = paste0("/api/v1/statuses/", id),
+        instance = instance,
+        anonymous = anonymous,
+        parse = parse,
+        FUN = parse_status
     )
 }
 
 #' @rdname get_status
 #' @export
-get_reblogged_by <- function(id, instance = NULL, token = NULL, anonymous = FALSE, parse = TRUE) {
+get_reblogged_by <- function(
+    id,
+    instance = NULL,
+    token = NULL,
+    anonymous = FALSE,
+    parse = TRUE
+) {
     process_request(
-        token = token, path = paste0("/api/v1/statuses/", id, "/reblogged_by"), instance = instance,
-        anonymous = anonymous, parse = parse, FUN = v(parse_account)
+        token = token,
+        path = paste0("/api/v1/statuses/", id, "/reblogged_by"),
+        instance = instance,
+        anonymous = anonymous,
+        parse = parse,
+        FUN = v(parse_account)
     )
 }
 
 #' @rdname get_status
 #' @export
-get_favourited_by <- function(id, instance = NULL, token = NULL, anonymous = FALSE, parse = TRUE) {
+get_favourited_by <- function(
+    id,
+    instance = NULL,
+    token = NULL,
+    anonymous = FALSE,
+    parse = TRUE
+) {
     process_request(
-        token = token, path = paste0("/api/v1/statuses/", id, "/favourited_by"), instance = instance,
-        anonymous = anonymous, parse = parse, FUN = v(parse_account)
+        token = token,
+        path = paste0("/api/v1/statuses/", id, "/favourited_by"),
+        instance = instance,
+        anonymous = anonymous,
+        parse = parse,
+        FUN = v(parse_account)
     )
 }
 
@@ -52,10 +82,20 @@ get_favourited_by <- function(id, instance = NULL, token = NULL, anonymous = FAL
 #' \dontrun{
 #' get_context(id = "109294719267373593", instance = "mastodon.social")
 #' }
-get_context <- function(id, instance = NULL, token = NULL, anonymous = FALSE, parse = TRUE) {
+get_context <- function(
+    id,
+    instance = NULL,
+    token = NULL,
+    anonymous = FALSE,
+    parse = TRUE
+) {
     process_request(
-        token = token, path = paste0("/api/v1/statuses/", id, "/context"), instance = instance,
-        anonymous = anonymous, parse = parse, FUN = parse_context
+        token = token,
+        path = paste0("/api/v1/statuses/", id, "/context"),
+        instance = instance,
+        anonymous = anonymous,
+        parse = parse,
+        FUN = parse_context
     )
 }
 
@@ -70,10 +110,20 @@ get_context <- function(id, instance = NULL, token = NULL, anonymous = FALSE, pa
 #' \dontrun{
 #' get_poll(id = "105976")
 #' }
-get_poll <- function(id, instance = NULL, token = NULL, anonymous = FALSE, parse = TRUE) {
+get_poll <- function(
+    id,
+    instance = NULL,
+    token = NULL,
+    anonymous = FALSE,
+    parse = TRUE
+) {
     process_request(
-        token = token, path = paste0("/api/v1/polls/", id), instance = instance,
-        anonymous = anonymous, parse = parse, FUN = parse_poll
+        token = token,
+        path = paste0("/api/v1/polls/", id),
+        instance = instance,
+        anonymous = anonymous,
+        parse = parse,
+        FUN = parse_poll
     )
 }
 
@@ -103,21 +153,42 @@ get_poll <- function(id, instance = NULL, token = NULL, anonymous = FALSE, parse
 #' }
 #' @references
 #' https://docs.joinmastodon.org/methods/timelines/
-get_timeline_public <- function(local = FALSE, remote = FALSE, only_media = FALSE,
-                                max_id, since_id, min_id, limit = 20L,
-                                instance = NULL, token = NULL, anonymous = FALSE, parse = TRUE,
-                                retryonratelimit = TRUE, verbose = TRUE) {
+get_timeline_public <- function(
+    local = FALSE,
+    remote = FALSE,
+    only_media = FALSE,
+    max_id,
+    since_id,
+    min_id,
+    limit = 20L,
+    instance = NULL,
+    token = NULL,
+    anonymous = FALSE,
+    parse = TRUE,
+    retryonratelimit = TRUE,
+    verbose = TRUE
+) {
     params <- handle_params(
         list(
-            local = local, remote = remote,
-            only_media = only_media, limit = min(limit, 40)
+            local = local,
+            remote = remote,
+            only_media = only_media,
+            limit = min(limit, 40)
         ),
-        max_id, since_id, min_id
+        max_id,
+        since_id,
+        min_id
     )
     process_request(
-        token = token, path = "/api/v1/timelines/public", instance = instance, params = params,
-        anonymous = anonymous, parse = parse, FUN = v(parse_status),
-        n = limit, retryonratelimit = retryonratelimit,
+        token = token,
+        path = "/api/v1/timelines/public",
+        instance = instance,
+        params = params,
+        anonymous = anonymous,
+        parse = parse,
+        FUN = v(parse_status),
+        n = limit,
+        retryonratelimit = retryonratelimit,
         verbose = verbose
     )
 }
@@ -138,16 +209,38 @@ get_timeline_public <- function(local = FALSE, remote = FALSE, only_media = FALS
 #' get_timeline_hashtag(hashtag = "ichbinhanna", instance = "mastodon.social", anonymous = TRUE,
 #' max_id = as.POSIXct("2024-03-01"))
 #' }
-get_timeline_hashtag <- function(hashtag = "rstats", local = FALSE, only_media = FALSE,
-                                 max_id, since_id, min_id, limit = 20L, instance = NULL,
-                                 token = NULL, anonymous = FALSE, parse = TRUE,
-                                 retryonratelimit = TRUE, verbose = TRUE) {
-    params <- handle_params(list(local = local, only_media = only_media, limit = min(limit, 40L)), max_id, since_id, min_id)
+get_timeline_hashtag <- function(
+    hashtag = "rstats",
+    local = FALSE,
+    only_media = FALSE,
+    max_id,
+    since_id,
+    min_id,
+    limit = 20L,
+    instance = NULL,
+    token = NULL,
+    anonymous = FALSE,
+    parse = TRUE,
+    retryonratelimit = TRUE,
+    verbose = TRUE
+) {
+    params <- handle_params(
+        list(local = local, only_media = only_media, limit = min(limit, 40L)),
+        max_id,
+        since_id,
+        min_id
+    )
     path <- paste0("/api/v1/timelines/tag/", gsub("^#+", "", hashtag))
     process_request(
-        token = token, path = path, instance = instance, params = params,
-        anonymous = anonymous, parse = parse, FUN = v(parse_status),
-        n = limit, retryonratelimit = retryonratelimit,
+        token = token,
+        path = path,
+        instance = instance,
+        params = params,
+        anonymous = anonymous,
+        parse = parse,
+        FUN = v(parse_status),
+        n = limit,
+        retryonratelimit = retryonratelimit,
         verbose = verbose
     )
 }
@@ -163,13 +256,31 @@ get_timeline_hashtag <- function(hashtag = "rstats", local = FALSE, only_media =
 #' \dontrun{
 #' get_timeline_home()
 #' }
-get_timeline_home <- function(local = FALSE, max_id, since_id, min_id, limit = 20L,
-                              token = NULL, parse = TRUE, retryonratelimit = TRUE, verbose = TRUE) {
-    params <- handle_params(list(local = local, limit = min(limit, 40L)), max_id, since_id, min_id)
+get_timeline_home <- function(
+    local = FALSE,
+    max_id,
+    since_id,
+    min_id,
+    limit = 20L,
+    token = NULL,
+    parse = TRUE,
+    retryonratelimit = TRUE,
+    verbose = TRUE
+) {
+    params <- handle_params(
+        list(local = local, limit = min(limit, 40L)),
+        max_id,
+        since_id,
+        min_id
+    )
     process_request(
-        token = token, path = "/api/v1/timelines/home", params = params,
-        parse = parse, FUN = v(parse_status),
-        n = limit, retryonratelimit = retryonratelimit,
+        token = token,
+        path = "/api/v1/timelines/home",
+        params = params,
+        parse = parse,
+        FUN = v(parse_status),
+        n = limit,
+        retryonratelimit = retryonratelimit,
         verbose = verbose
     )
 }
@@ -180,14 +291,31 @@ get_timeline_home <- function(local = FALSE, max_id, since_id, min_id, limit = 2
 #' \dontrun{
 #' get_timeline_list("<listid>")
 #' }
-get_timeline_list <- function(list_id, max_id, since_id, min_id,
-                              limit = 20L, token = NULL, parse = TRUE,
-                              retryonratelimit = TRUE, verbose = TRUE) {
-    params <- handle_params(list(limit = min(limit, 40L)), max_id, since_id, min_id)
+get_timeline_list <- function(
+    list_id,
+    max_id,
+    since_id,
+    min_id,
+    limit = 20L,
+    token = NULL,
+    parse = TRUE,
+    retryonratelimit = TRUE,
+    verbose = TRUE
+) {
+    params <- handle_params(
+        list(limit = min(limit, 40L)),
+        max_id,
+        since_id,
+        min_id
+    )
     process_request(
-        token = token, path = paste0("/api/v1/timelines/list/", list_id), params = params,
-        parse = parse, FUN = v(parse_status),
-        n = limit, retryonratelimit = retryonratelimit,
+        token = token,
+        path = paste0("/api/v1/timelines/list/", list_id),
+        params = params,
+        parse = parse,
+        FUN = v(parse_status),
+        n = limit,
+        retryonratelimit = retryonratelimit,
         verbose = verbose
     )
 }
