@@ -1,6 +1,12 @@
 #' @export
 print.rtoot_bearer <- function(x, ...) {
-    cat("<mastodon bearer token> for instance:", x$instance, "of type:", x$type, "\n")
+    cat(
+        "<mastodon bearer token> for instance:",
+        x$instance,
+        "of type:",
+        x$type,
+        "\n"
+    )
     invisible(x)
 }
 
@@ -24,29 +30,56 @@ print.rtoot_bearer <- function(x, ...) {
 #' rtoot(endpoint = "api/v1/notifications", params = list(limit = 8))
 #' rtoot(endpoint = "api/v1/followed_tags")
 #' ## reimplement `get_timeline_public`
-#' rtoot(endpoint = "api/v1/timelines/public", instance = "emacs.ch", local = TRUE, anonymous = TRUE)
+#' rtoot(
+#'   endpoint = "api/v1/timelines/public",
+#'   instance = "mastodon.social",
+#'   local = TRUE,
+#'   anonymous = TRUE
+#' )
 #' }
-rtoot <- function(endpoint, ..., params = list(), token = NULL, instance = NULL,
-                  anonymous = FALSE) {
+rtoot <- function(
+    endpoint,
+    ...,
+    params = list(),
+    token = NULL,
+    instance = NULL,
+    anonymous = FALSE
+) {
     if (missing(endpoint)) {
-        stop("Please provide an `endpoint`", call. = FALSE)
+        cli::cli_abort("Please provide an `endpoint`", call. = FALSE)
     }
     params <- c(list(...), params)
-    make_get_request(token = token, path = endpoint, params = params, instance = instance, anonymous = anonymous)
+    make_get_request(
+        token = token,
+        path = endpoint,
+        params = params,
+        instance = instance,
+        anonymous = anonymous
+    )
 }
 
 ## Endpoints under
 ## https://docs.joinmastodon.org/methods/statuses/
 ## https://docs.joinmastodon.org/methods/timelines/
 
-make_get_request <- function(token, path, params = list(), instance = NULL, anonymous = FALSE, max_error = 4, ...) {
+make_get_request <- function(
+    token,
+    path,
+    params = list(),
+    instance = NULL,
+    anonymous = FALSE,
+    max_error = 4,
+    ...
+) {
     if (is.null(instance) && anonymous) {
-        stop("provide either an instance or a token", call. = FALSE)
+        cli::cli_abort("provide either an instance or a token", call. = FALSE)
     }
     if (is.null(instance)) {
         token <- check_token_rtoot(token)
         url <- prepare_url(token$instance)
-        config <- httr::add_headers(Authorization = paste("Bearer", token$bearer))
+        config <- httr::add_headers(
+            Authorization = paste("Bearer", token$bearer)
+        )
     } else {
         url <- prepare_url(instance)
         config <- list()
@@ -54,18 +87,22 @@ make_get_request <- function(token, path, params = list(), instance = NULL, anon
     count <- 0
     while (TRUE) {
         if (count >= max_error) {
-            stop("Too many errors.")
+            cli::cli_abort("Too many errors.")
         }
-        request_results <- httr::GET(httr::modify_url(url, path = path),
+        request_results <- httr::GET(
+            httr::modify_url(url, path = path),
             config,
             query = params
         )
 
         status_code <- httr::status_code(request_results)
         if (!status_code %in% c(200, 429)) {
-            stop(paste("Unable to make the request. Status Code: ", status_code), call. = FALSE)
+            cli::cli_abort(
+                paste("Unable to make the request. Status Code: ", status_code),
+                call. = FALSE
+            )
         } else if (status_code == 429) {
-            message("too many requests. Sleeping for 5 minutes")
+            cli::cli_inform("too many requests. Sleeping for 5 minutes")
             Sys.sleep(60 * 5)
             count <- count + 1
         } else if (status_code == 200) {
@@ -95,7 +132,10 @@ parse_header <- function(header) {
     )
     if ("link" %in% names(header)) {
         vars_to_search <- c("max_id", "min_id", "since_id")
-        links <- regmatches(header[["link"]], gregexpr("https[^>]+", header[["link"]]))[[1]]
+        links <- regmatches(
+            header[["link"]],
+            gregexpr("https[^>]+", header[["link"]])
+        )[[1]]
         query_params <- lapply(links, function(x) {
             query <- httr::parse_url(x)[["query"]]
             query <- query[names(query) %in% vars_to_search]
@@ -109,17 +149,19 @@ parse_header <- function(header) {
 }
 
 # process a get request and parse output
-process_request <- function(token = NULL,
-                            path,
-                            instance = NULL,
-                            params = list(),
-                            anonymous = FALSE,
-                            parse = TRUE,
-                            FUN = identity,
-                            n = 1L,
-                            page_size = 40L,
-                            retryonratelimit = TRUE,
-                            verbose = TRUE) {
+process_request <- function(
+    token = NULL,
+    path,
+    instance = NULL,
+    params = list(),
+    anonymous = FALSE,
+    parse = TRUE,
+    FUN = identity,
+    n = 1L,
+    page_size = 40L,
+    retryonratelimit = TRUE,
+    verbose = TRUE
+) {
     # if since_id is provided we page forward, otherwise we page backwards
     if (!is.null(params[["since_id"]])) {
         pager <- "since_id"
@@ -136,16 +178,22 @@ process_request <- function(token = NULL,
     }
     for (i in seq_len(pages)) {
         api_response <- make_get_request(
-            token = token, path = path,
-            instance = instance, params = params,
+            token = token,
+            path = path,
+            instance = instance,
+            params = params,
             anonymous = anonymous
         )
         output <- c(output, api_response)
         attr(output, "headers") <- attr(api_response, "headers")
-        if (break_process_request(
-            api_response = api_response, retryonratelimit = retryonratelimit,
-            verbose = verbose, pager = pager
-        )) {
+        if (
+            break_process_request(
+                api_response = api_response,
+                retryonratelimit = retryonratelimit,
+                verbose = verbose,
+                pager = pager
+            )
+        ) {
             break
         }
         params[[pager]] <- attr(api_response, "headers")[[pager]]
@@ -175,7 +223,7 @@ v <- function(FUN) {
 
 sayif <- function(verbose, ...) {
     if (isTRUE(verbose)) {
-        message(...)
+        cli::cli_inform(paste(c(...), collapse = ""))
     }
 }
 
@@ -191,11 +239,13 @@ wait_until <- function(until, from = Sys.time(), verbose = TRUE) {
 
 rate_limit_remaining <- function(object) {
     if (is.null(attr(object, "headers"))) {
-        stop("no header information found")
+        cli::cli_abort("no header information found")
     }
     header <- attr(object, "headers")
     if (is.null(header[["rate_remaining"]])) {
-        warning("no rate limit information found. Setting it to the default", call. = FALSE)
+        cli::cli_warn(
+            "no rate limit information found. Setting it to the default"
+        )
         return(300)
     } else {
         return(as.numeric(header[["rate_remaining"]]))
@@ -203,7 +253,12 @@ rate_limit_remaining <- function(object) {
 }
 
 ## A kind of drop-in replacement of utils::menu, with a plus
-rtoot_menu <- function(choices = c("yes", "no"), title, default = 2L, verbose = TRUE) {
+rtoot_menu <- function(
+    choices = c("yes", "no"),
+    title,
+    default = 2L,
+    verbose = TRUE
+) {
     if (!is.null(options("rtoot_cheatcode")$rtoot_cheatcode)) {
         if (options("rtoot_cheatcode")$rtoot_cheatcode == "uuddlrlrba") {
             sayif(verbose, title)
@@ -217,7 +272,13 @@ rtoot_menu <- function(choices = c("yes", "no"), title, default = 2L, verbose =
 }
 
 ## A kind of drop-in replacement of base:readline, with a plus
-rtoot_ask <- function(prompt = "enter authorization code: ", pass = TRUE, check_rstudio = TRUE, default = "pass", verbose = TRUE) {
+rtoot_ask <- function(
+    prompt = "enter authorization code: ",
+    pass = TRUE,
+    check_rstudio = TRUE,
+    default = "pass",
+    verbose = TRUE
+) {
     if (!is.null(options("rtoot_cheatcode")$rtoot_cheatcode)) {
         if (options("rtoot_cheatcode")$rtoot_cheatcode == "uuddlrlrba") {
             sayif(verbose, prompt)
@@ -229,7 +290,11 @@ rtoot_ask <- function(prompt = "enter authorization code: ", pass = TRUE, check_
         return(default)
     }
     passFun <- readline
-    if (isTRUE(pass) && isTRUE(check_rstudio) && (requireNamespace("rstudioapi", quietly = TRUE))) {
+    if (
+        isTRUE(pass) &&
+            isTRUE(check_rstudio) &&
+            (requireNamespace("rstudioapi", quietly = TRUE))
+    ) {
         if (rstudioapi::isAvailable() && rstudioapi::hasFun("askForPassword")) {
             passFun <- rstudioapi::askForPassword
         }
@@ -259,16 +324,29 @@ handle_params <- function(params, max_id, since_id, min_id) {
 }
 
 ## a predicate to determine whether to break away from the for-loop of process_request
-break_process_request <- function(api_response, retryonratelimit = FALSE, verbose = FALSE, pager = "max_id", from = Sys.time()) {
+break_process_request <- function(
+    api_response,
+    retryonratelimit = FALSE,
+    verbose = FALSE,
+    pager = "max_id",
+    from = Sys.time()
+) {
     if (is.null(attr(api_response, "headers")[[pager]])) {
         return(TRUE)
     }
     if (rate_limit_remaining(api_response) == 0 && isTRUE(retryonratelimit)) {
-        wait_until(until = attr(api_response, "headers")[["rate_reset"]], from = from, verbose = verbose)
+        wait_until(
+            until = attr(api_response, "headers")[["rate_reset"]],
+            from = from,
+            verbose = verbose
+        )
         return(FALSE)
     }
     if (rate_limit_remaining(api_response) == 0 && isFALSE(retryonratelimit)) {
-        sayif(verbose, "rate limit reached and `retryonratelimit=FALSE`. returning current results.")
+        sayif(
+            verbose,
+            "rate limit reached and `retryonratelimit=FALSE`. returning current results."
+        )
         return(TRUE)
     }
     return(FALSE)
