@@ -28,16 +28,20 @@ test_that("handle_params", {
 test_that("integration test", {
   ## The old wiki example; it use max_id
   vcr::use_cassette("handle_params_max_id", {
-  max_id <- NULL
-  output <- tibble::tibble()
-  for (i in 1:4) {
-    res <- get_timeline_hashtag(hashtag = "ichbinhanna", max_id = max_id,
-                                limit = 40, instance = "mastodon.social",
-                                anonymous = TRUE)
-    output <- rbind(res, output)
-    max_id <- res$id[res$created_at == min(res$created_at)]
-    Sys.sleep(1)
-  }
+    max_id <- NULL
+    output <- tibble::tibble()
+    for (i in 1:4) {
+      res <- get_timeline_hashtag(
+        hashtag = "ichbinhanna",
+        max_id = max_id,
+        limit = 40,
+        instance = "mastodon.social",
+        anonymous = TRUE
+      )
+      output <- rbind(res, output)
+      max_id <- res$id[res$created_at == min(res$created_at)]
+      Sys.sleep(1)
+    }
   })
   expect_equal(nrow(output), 160)
   expect_equal(length(unique(output$id)), 160) ## all unique
